@@ -235,7 +235,7 @@ iVTK::iVTK(QWidget *parent, const char *name) : iRenderWindow(parent,name)
 	
 	id = idCounter++;
 
-	imageType = I_IMAGETYPE_JPG;
+	imageType = I_IMAGETYPE_PNG;
 
 	fontSize = 16;
 	fontType = 0;
@@ -1227,7 +1227,7 @@ void iVTK::render(bool s)
 #endif
 		obsAbortRender->start();
 	}
-	ren->ResetCameraClippingRange();
+      	ren->ResetCameraClippingRange();
 	this->Render();
 	if(s)
 	{
